@@ -1,6 +1,8 @@
 import json
+from datetime import date
 
 from stapy.sta.geo import GeoJSON
+from stapy.sta.time import Time
 
 def default(typ):
     switch = {
@@ -9,7 +11,8 @@ def default(typ):
         float: 0.0,
         dict: {},
         list: [],
-        object: None
+        object: None,
+        Time: date.today().isoformat(),
     }
     return switch.get(typ, None)
 
@@ -19,11 +22,14 @@ def cast(typ, value):
         int: int,
         float: float,
         dict: json.loads,
-        GeoJSON: GeoJSON.match
+        GeoJSON: GeoJSON.match,
+        Time: Time,
     }
     return switch.get(typ)(value)
 
 def un_cast(value):
     if isinstance(value, GeoJSON):
         return value.value
+    if isinstance(value, Time):
+        return str(value)
     return value
